#回帰モデルと説明・予測の向き

#目的変数：残業時間 overtime
#説明変数：勤続年数 tenure
#　　　　　部門 section（Ademin, IT, Sales ）

#データの読込み
DF <- read.table("StaffOvertime.csv",
                  sep = ",",                #カンマ区切りのファイル
                  header = TRUE,            #1行目はヘッダー(列名)
                  stringsAsFactors = FALSE) #文字列を文字列型で取込む

#管理部門のみを取り出す
#関数subset()で条件に合うデータだけを抽出する
DFsub <- subset(DF, section=="Admin")  　#!=はnot equalを示す

#データフレームの先頭を表示
head(DFsub)

#勤続年数から残業時間を説明するモデル LMyx
LMyx <- lm( overtime ~ tenure, data=DFsub)
summary(LMyx)

#回帰係数の値を取り出す
b0yx <- LMyx$coefficients[1]
b1yx <- LMyx$coefficients[2]

#LMyxの回帰式
# y = b0yx + b1yx * x

#ggplot()でモデルを図示
library(ggplot2)

#プロットをいったんgという名称で保存
g <- ggplot() +
  geom_point( aes(x=DFsub$tenure, y=DFsub$overtime),    #データの指定
              colour="gray50", size=3, alpha=0.7 ) + #色,サイズ,透明度
  # stat_function()を使うと関数f(x)を直線または曲線でプロットできる
  stat_function(colour="cyan4", size=1,
                fun=function(x) b0yx + b1yx * x) +
  xlim(0, 40) +
  ylim(0, 50) +
  theme_bw()

#プロットを表示
g


#勤続年数が30年の場合の残業時間の値を予測

#勤続年数xが30のときの残業時間yの値（LMyx）
y_x30  <- b0yx + b1yx * 30
y_x30
#勤続年数が30年前後（±5年）のケースの残業時間の平均
mean(DFsub$overtime[DFsub$tenure<35 & DFsub$tenure>25])

#予測値を表わす線分をプロットに追加して表示
g1 <- g +
  geom_vline(xintercept=30, colour="gray50", alpha=0.6) +
  geom_path(aes(x=c(30, 0), y=c(y_x30, y_x30)), 
            colour="cyan3", size=0.2, alpha=0.8, 
            arrow=arrow(type="closed", length=unit(0.25, "cm"))) 
g1


#残業時間から勤続年数を説明するモデル LMxy
LMxy <- lm( tenure ~ overtime, data=DFsub)
summary(LMxy)

#回帰係数の値を取り出す
b0xy <- LMxy$coefficients[1]
b1xy <- LMxy$coefficients[2]

#LMxyについてyを左辺にした式を考える
# x = b0xy + b1xy * y
# y = (x - b0xy) / b1xy
#   = -(b0xy/b1xy) + (1/b1xy) * x

#最初に作った散布図にLMxyを追加して図示
g <- g +
  stat_function(colour="magenta3", size=1, 
                fun=function(x) -(b0xy/b1xy) + (1/b1xy) * x)
g


#残業時間が30時間の場合の勤続年数の値を予測

#残業時間yが30のときの勤続年数xの値（LMxy）
x_y30  <- b0xy + b1xy * 30
x_y30
#残業時間が30時間前後（±5時間）のケースの勤続年数の平均
mean(DFsub$tenure[DFsub$overtime<35 & DFsub$overtime>25])

#残業時間yが30のときの勤続年数xの値（LMyxによる逆推定値）
x_y30R  <- -(b0yx/b1yx) + (1/b1yx) * 30
x_y30R

#予測値を表わす線分をプロットに追加して表示
g2 <- g +
   geom_hline(yintercept=30, colour="gray50", alpha=0.6) +
   geom_path(aes(x=c(x_y30, x_y30), y=c(30, 0)), 
             colour="magenta", size=0.2, alpha=0.9, linetype="dashed",  
             arrow=arrow(type="closed", length=unit(0.25, "cm"))) +
   geom_path(aes(x=c(x_y30R, x_y30R), y=c(30, 0)), 
             colour="cyan3", size=0.2, alpha=0.8, 
             arrow=arrow(type="closed", length=unit(0.25, "cm"))) 
g2
