#構造方程式モデリング

#ライブラリの読み込み
library(lavaan)
library(semPlot)
library(lm.beta)

#データの読込み（モチベーション）
DF1 <- read.table("ESSurvey.csv", sep=",", header=TRUE)
summary(DF1)

#スタッフのモチベーション：Score
#10人あたりの年間の業務評価面接回数：Meeting
#3年間に職務や待遇の変化があった人数の比率：Reassign

#通常の線形回帰
summary(lm.beta( lm(Score ~ Meeting + Reassign, data=DF1)) )

#SEM（重回帰モデルの例）
#モデルの定義
Model1 <- "Score ~ Meeting + Reassign"
#SEMの実行
result1 <- sem(Model1, data=DF1)
#結果（標準化されたパス係数と適合度指標を表示）
summary(result1, standardized=T, fit.measure=T)

#パス図
semPaths(result1, 
         whatLabels="stand",     #標準化係数を表示
         layout="tree",          #パス図の形状 
         style="lisrel",         #情報表示の様式
         nCharNodes=8,           #文字数上限(0:全て表示)
         sizeMan=20, sizeMan2=5, #manifest nodeの幅
         sizeLat=20, sizeLat2=5, #latent nodeの幅
         sizeInt=20, sizeInt2=5, #vector nodeの幅
         nDigits=3,              #小数点以下
         edge.label.cex=2.0)     #数字の大きさ

# 飽和モデル(自由度df=0)であり、適合度は評価できない
# パス係数の大きさと有意確率を評価する


#データの読込み（地域の環境と愛着）
DF2 <- read.table("liveability.csv", sep=",", header=TRUE,
                 fileEncoding="UTF-8")
summary(DF2)

#各調査項目(6項目)について1から9までの数値で評価

#調査項目どうしの相関
round(cor(DF2), 2)

#SEM（潜在変数モデルの例）
#モデルの定義と実行
Model2 <- "愛着 ~ 環境
           愛着 =~ 良い街だ + 住みやすい + 住み続けたい
           環境 =~ 緑が多い + 景観が良い + 騒音が多い "
result2 <- sem(Model2, data=DF2)
summary(result2, standardized=T, fit.measure=T)

#パス図
semPaths(result2, 
         whatLabels="stand",     #標準化係数を表示
         layout="tree",          #パス図の形状 
         style="lisrel",         #情報表示の様式
         nCharNodes=8,           #文字数上限(0:全て表示)
         sizeMan=20, sizeMan2=4, #manifest nodeの幅
         sizeLat=15, sizeLat2=4, #latent nodeの幅
         sizeInt=20, sizeInt2=4, #vector nodeの幅
         nDigits=3,              #小数点以下
         edge.label.cex=1.5)     #数字の大きさ
