#ベイジアンネットワーク

#ライブラリの読み込み
library(bnlearn)

#データの読み込み
DF <- read.table(file="incident.csv", sep=",", header=T,
                 stringsAsFactors=T)
#先頭を表示
head(DF)

#長時間労働の有無　　　：labour
#運転手の疲労の有無　　：weary
#ヒヤリハット事例の有無：incident
#天候(晴/曇/雨)　　　　：weather

#sapply()を使って列単位に関数table()で頻度を表示
sapply(DF, table)

#ヒルクライム法による探索
netw <- hc(DF, debug=T)
plot(netw)

ブラックリストを設定
b <- c("incident", "weather")

#ヒルクライム法による再探索
netw <- hc(DF, blacklist=b)
plot(netw)

#ブラックリストに要素を追加
#rbind()で新しい行として結合する
b <- rbind(b, c("incident", "weary"))

#ヒルクライム法による再探索
netw <- hc(DF, blacklist=b)
plot(netw)

#探索された構造をもとに条件付き確率を算出
result <- bn.fit(netw, data=DF)
#条件付き確率を表示
coefficients(result)

#算出された条件付き確率をもとに予測を行う
#ここではモデルに元のデータを当てはめて予測
pred_incident <- predict(result, "incident", DF)

#実際のデータとの一致度合いを確認
table(DF$incident, pred_incident)
